@@ -25,7 +25,7 @@ from __future__ import annotations
 
 from copy import deepcopy
 from math import log
-from typing import Callable, Optional
+from typing import Any, Callable, Optional
 
 import torch
 from botorch.acquisition.cost_aware import CostAwareUtility, InverseCostWeightedUtility
@@ -35,6 +35,7 @@ from botorch.models.model import Model
 from botorch.models.utils import check_no_nans
 from botorch.sampling.samplers import SobolQMCNormalSampler
 from botorch.utils.transforms import match_batch_shape, t_batch_mode_transform
+from gpytorch.utils.cholesky import psd_safe_cholesky
 from scipy.optimize import brentq
 from torch import Tensor
 
@@ -70,6 +71,7 @@ class qMaxValueEntropy(MCAcquisitionFunction):
         use_gumbel: bool = True,
         maximize: bool = True,
         X_pending: Optional[Tensor] = None,
+        **kwargs: Any,
     ) -> None:
         r"""Single-outcome max-value entropy search acquisition function.
 
@@ -239,7 +241,7 @@ class qMaxValueEntropy(MCAcquisitionFunction):
         # compute mean and std for fM|ym, x, Dt ~ N(u, s^2)
         samples_m = self.weight * self.sampler(posterior_m).squeeze(-1)
         # s_m x batch_shape x num_fantasies x (1 + num_trace_observations)
-        L = torch.cholesky(variance_m)
+        L = psd_safe_cholesky(variance_m)
         temp_term = torch.cholesky_solve(covar_mM.unsqueeze(-1), L).transpose(-2, -1)
         # equivalent to torch.matmul(covar_mM.unsqueeze(-2), torch.inverse(variance_m))
         # batch_shape x num_fantasies x 1 x (1 + num_trace_observations)
@@ -336,6 +338,7 @@ class qMultiFidelityMaxValueEntropy(qMaxValueEntropy):
         cost_aware_utility: Optional[CostAwareUtility] = None,
         project: Callable[[Tensor], Tensor] = lambda X: X,
         expand: Callable[[Tensor], Tensor] = lambda X: X,
+        **kwargs: Any,
     ) -> None:
         r"""Single-outcome max-value entropy search acquisition function.
 
