@@ -19,6 +19,7 @@ from botorch.acquisition.multi_objective.objective import (
     MCMultiOutputObjective,
     UnstandardizeAnalyticMultiOutputObjective,
     UnstandardizeMCMultiOutputObjective,
+    WeightedMCMultiOutputObjective,
 )
 
 
@@ -33,4 +34,5 @@ __all__ = [
     "qExpectedHypervolumeImprovement",
     "UnstandardizeAnalyticMultiOutputObjective",
     "UnstandardizeMCMultiOutputObjective",
+    "WeightedMCMultiOutputObjective",
 ]
