@@ -14,6 +14,7 @@ from typing import Any, Dict, List, Optional, Tuple
 
 import torch
 from botorch.models.gpytorch import MultiTaskGPyTorchModel
+from botorch.models.transforms.input import InputTransform
 from botorch.utils.containers import TrainingData
 from gpytorch.distributions.multivariate_normal import MultivariateNormal
 from gpytorch.kernels.index_kernel import IndexKernel
@@ -25,6 +26,7 @@ from gpytorch.likelihoods.gaussian_likelihood import (
 )
 from gpytorch.means.constant_mean import ConstantMean
 from gpytorch.models.exact_gp import ExactGP
+from gpytorch.priors.lkj_prior import LKJCovariancePrior
 from gpytorch.priors.prior import Prior
 from gpytorch.priors.torch_priors import GammaPrior
 from torch import Tensor
@@ -48,9 +50,10 @@ class MultiTaskGP(ExactGP, MultiTaskGPyTorchModel):
         train_X: Tensor,
         train_Y: Tensor,
         task_feature: int,
-        prior: Optional[Prior] = None,
+        task_covar_prior: Optional[Prior] = None,
         output_tasks: Optional[List[int]] = None,
         rank: Optional[int] = None,
+        input_transform: Optional[InputTransform] = None,
     ) -> None:
         r"""Multi-Task GP model using an ICM kernel, inferring observation noise.
 
@@ -64,6 +67,10 @@ class MultiTaskGP(ExactGP, MultiTaskGPyTorchModel):
                 outputs for. If omitted, return outputs for all task indices.
             rank: The rank to be used for the index kernel. If omitted, use a
                 full rank (i.e. number of tasks) kernel.
+            task_covar_prior : A Prior on the task covariance matrix. Must operate
+                on p.s.d. matrices. A common prior for this is the `LKJ` prior.
+            input_transform: An input transform that is applied in the model's
+                forward pass.
 
         Example:
             >>> X1, X2 = torch.rand(10, 2), torch.rand(20, 2)
@@ -74,8 +81,14 @@ class MultiTaskGP(ExactGP, MultiTaskGPyTorchModel):
             >>> train_Y = torch.cat(f1(X1), f2(X2)).unsqueeze(-1)
             >>> model = MultiTaskGP(train_X, train_Y, task_feature=-1)
         """
+        if input_transform is not None:
+            input_transform.to(train_X)
+        transformed_X = self.transform_inputs(
+            X=train_X, input_transform=input_transform
+        )
+        self._validate_tensor_args(X=transformed_X, Y=train_Y)
         all_tasks, task_feature, d = self.get_all_tasks(
-            train_X, task_feature, output_tasks
+            transformed_X, task_feature, output_tasks
         )
         # squeeze output dim
         train_Y = train_Y.squeeze(-1)
@@ -109,8 +122,10 @@ class MultiTaskGP(ExactGP, MultiTaskGPyTorchModel):
         self._rank = rank if rank is not None else num_tasks
 
         self.task_covar_module = IndexKernel(
-            num_tasks=num_tasks, rank=self._rank, prior=prior
+            num_tasks=num_tasks, rank=self._rank, prior=task_covar_prior
         )
+        if input_transform is not None:
+            self.input_transform = input_transform
         self.to(train_X)
 
     def _split_inputs(self, x: Tensor) -> Tuple[Tensor, Tensor]:
@@ -121,7 +136,7 @@ class MultiTaskGP(ExactGP, MultiTaskGPyTorchModel):
                 Should be of float/double data type.
 
         Returns:
-            2-element tuple containin
+            2-element tuple containing
 
             - A `q x d` or `b x q x d` (batch mode) tensor with trailing
             dimension made up of the `d` non-task-index columns of `x`, arranged
@@ -140,6 +155,7 @@ class MultiTaskGP(ExactGP, MultiTaskGPyTorchModel):
         return x_basic, task_idcs
 
     def forward(self, x: Tensor) -> MultivariateNormal:
+        x = self.transform_inputs(x)
         x_basic, task_idcs = self._split_inputs(x)
         # Compute base mean and covariance
         mean_x = self.mean_module(x_basic)
@@ -169,27 +185,58 @@ class MultiTaskGP(ExactGP, MultiTaskGPyTorchModel):
 
     @classmethod
     def construct_inputs(cls, training_data: TrainingData, **kwargs) -> Dict[str, Any]:
-        r"""Construct kwargs for the `Model` from `TrainingData`.
+        r"""Construct kwargs for the `Model` from `TrainingData` and other options.
 
         Args:
             training_data: `TrainingData` container with data for single outcome
                 or for multiple outcomes for batched multi-output case.
             **kwargs: Additional options for the model that pertain to the
-                training data:
-                - `task_features` – indices of the input columns containing the task
-                features (expected list of length 1).
+                training data, including:
+
+                - `task_features`: Indices of the input columns containing the task
+                  features (expected list of length 1),
+                - `task_covar_prior`: A GPyTorch `Prior` object to use as prior on
+                  the cross-task covariance matrix,
+                - `prior_config`: A dict representing a prior config, should only be
+                  used if `prior` is not passed directly. Should contain:
+                  `use_LKJ_prior` (whether to use LKJ prior) and `eta` (eta value,
+                  float),
+                - `rank`: The rank of the cross-task covariance matrix.
         """
 
-        task_features = kwargs.get("task_features")
+        task_features = kwargs.pop("task_features", None)
         if task_features is None:
-            raise ValueError(f"task features required for {cls.__name__}.")
-
-        return {
+            raise ValueError(f"`task_features` required for {cls.__name__}.")
+        task_feature = task_features[0]
+        inputs = {
             "train_X": training_data.X,
             "train_Y": training_data.Y,
-            "task_feature": task_features[0],
+            "task_feature": task_feature,
+            "rank": kwargs.get("rank"),
         }
 
+        prior = kwargs.get("task_covar_prior")
+        prior_config = kwargs.get("prior_config")
+        if prior and prior_config:
+            raise ValueError(
+                "Only one of `prior` and `prior_config` arguments expected."
+            )
+
+        if prior_config:
+            if not prior_config.get("use_LKJ_prior"):
+                raise ValueError("Currently only config for LKJ prior is supported.")
+            all_tasks, _, _ = MultiTaskGP.get_all_tasks(training_data.X, task_feature)
+            num_tasks = len(all_tasks)
+            sd_prior = GammaPrior(1.0, 0.15)
+            sd_prior._event_shape = torch.Size([num_tasks])
+            eta = prior_config.get("eta", 0.5)
+            if not isinstance(eta, float) and not isinstance(eta, int):
+                raise ValueError(f"eta must be a real number, your eta was {eta}.")
+            prior = LKJCovariancePrior(num_tasks, eta, sd_prior)
+
+        inputs["task_covar_prior"] = prior
+        return inputs
+
 
 class FixedNoiseMultiTaskGP(MultiTaskGP):
     r"""Multi-Task GP model using an ICM kernel, with known observation noise.
@@ -208,11 +255,12 @@ class FixedNoiseMultiTaskGP(MultiTaskGP):
         train_Y: Tensor,
         train_Yvar: Tensor,
         task_feature: int,
-        prior: Optional[Prior] = None,
+        task_covar_prior: Optional[Prior] = None,
         output_tasks: Optional[List[int]] = None,
         rank: Optional[int] = None,
+        input_transform: Optional[InputTransform] = None,
     ) -> None:
-        r"""Multi-Task GP model using an ICM kernel and known observatioon noise.
+        r"""Multi-Task GP model using an ICM kernel and known observation noise.
 
         Args:
             train_X: A `n x (d + 1)` or `b x n x (d + 1)` (batch mode) tensor
@@ -223,10 +271,14 @@ class FixedNoiseMultiTaskGP(MultiTaskGP):
             train_Yvar: A `n` or `b x n` (batch mode) tensor of observation
                 noise standard errors.
             task_feature: The index of the task feature (`-d <= task_feature <= d`).
+            task_covar_prior : A Prior on the task covariance matrix. Must operate
+                on p.s.d. matrices. A common prior for this is the `LKJ` prior.
             output_tasks: A list of task indices for which to compute model
                 outputs for. If omitted, return outputs for all task indices.
             rank: The rank to be used for the index kernel. If omitted, use a
                 full rank (i.e. number of tasks) kernel.
+            input_transform: An input transform that is applied in the model's
+                forward pass.
 
         Example:
             >>> X1, X2 = torch.rand(10, 2), torch.rand(20, 2)
@@ -238,7 +290,12 @@ class FixedNoiseMultiTaskGP(MultiTaskGP):
             >>> train_Yvar = 0.1 + 0.1 * torch.rand_like(train_Y)
             >>> model = FixedNoiseMultiTaskGP(train_X, train_Y, train_Yvar, -1)
         """
-        self._validate_tensor_args(X=train_X, Y=train_Y, Yvar=train_Yvar)
+        if input_transform is not None:
+            input_transform.to(train_X)
+        transformed_X = self.transform_inputs(
+            X=train_X, input_transform=input_transform
+        )
+        self._validate_tensor_args(X=transformed_X, Y=train_Y, Yvar=train_Yvar)
         # We'll instatiate a MultiTaskGP and simply override the likelihood
         super().__init__(
             train_X=train_X,
@@ -246,32 +303,35 @@ class FixedNoiseMultiTaskGP(MultiTaskGP):
             task_feature=task_feature,
             output_tasks=output_tasks,
             rank=rank,
-            prior=prior,
+            task_covar_prior=task_covar_prior,
+            input_transform=input_transform,
         )
         self.likelihood = FixedNoiseGaussianLikelihood(noise=train_Yvar.squeeze(-1))
         self.to(train_X)
 
     @classmethod
     def construct_inputs(cls, training_data: TrainingData, **kwargs) -> Dict[str, Any]:
-        r"""Construct kwargs for the `Model` from `TrainingData`.
+        r"""Construct kwargs for the `Model` from `TrainingData` and other options.
 
         Args:
             training_data: `TrainingData` container with data for single outcome
                 or for multiple outcomes for batched multi-output case.
             **kwargs: Additional options for the model that pertain to the
-                training data:
-                - `task_features` – indices of task features in X.
-        """
+                training data, including:
 
-        task_features = kwargs.get("task_features")
-        if task_features is None:
-            raise ValueError(f"task features required for {cls.__name__}.")
+                - `task_features`: Indices of the input columns containing the task
+                  features (expected list of length 1),
+                - `task_covar_prior`: A GPyTorch `Prior` object to use as prior on
+                  the cross-task covariance matrix,
+                - `prior_config`: A dict representing a prior config, should only be
+                  used if `prior` is not passed directly. Should contain:
+                  use_LKJ_prior` (whether to use LKJ prior) and `eta` (eta value,
+                  float),
+                - `rank`: The rank of the cross-task covariance matrix.
+        """
         if training_data.Yvar is None:
             raise ValueError(f"Yvar required for {cls.__name__}.")
 
-        return {
-            "train_X": training_data.X,
-            "train_Y": training_data.Y,
-            "train_Yvar": training_data.Yvar,
-            "task_feature": task_features[0],
-        }
+        inputs = super().construct_inputs(training_data=training_data, **kwargs)
+        inputs["train_Yvar"] = training_data.Yvar
+        return inputs
