@@ -9,6 +9,20 @@ from botorch.test_functions.multi_fidelity import (
     AugmentedHartmann,
     AugmentedRosenbrock,
 )
+from botorch.test_functions.multi_objective import (
+    BNH,
+    C2DTLZ2,
+    CONSTR,
+    DTLZ1,
+    DTLZ2,
+    SRN,
+    ZDT1,
+    ZDT2,
+    ZDT3,
+    BraninCurrin,
+    ConstrainedBraninCurrin,
+    VehicleSafety,
+)
 from botorch.test_functions.synthetic import (
     Ackley,
     Beale,
@@ -40,11 +54,18 @@ __all__ = [
     "AugmentedHartmann",
     "AugmentedRosenbrock",
     "Beale",
+    "BNH",
     "Branin",
+    "BraninCurrin",
     "Bukin",
+    "CONSTR",
     "Cosine8",
+    "ConstrainedBraninCurrin",
+    "C2DTLZ2",
     "DixonPrice",
     "DropWave",
+    "DTLZ1",
+    "DTLZ2",
     "EggHolder",
     "Griewank",
     "Hartmann",
@@ -56,7 +77,12 @@ __all__ = [
     "Rosenbrock",
     "Shekel",
     "SixHumpCamel",
+    "SRN",
     "StyblinskiTang",
     "SyntheticTestFunction",
     "ThreeHumpCamel",
+    "VehicleSafety",
+    "ZDT1",
+    "ZDT2",
+    "ZDT3",
 ]
