@@ -4,6 +4,7 @@
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
+import itertools
 import math
 import warnings
 
@@ -11,6 +12,7 @@ import torch
 from botorch.exceptions.warnings import OptimizationWarning
 from botorch.fit import fit_gpytorch_model
 from botorch.models.multitask import FixedNoiseMultiTaskGP, MultiTaskGP
+from botorch.models.transforms.input import Normalize
 from botorch.posteriors import GPyTorchPosterior
 from botorch.utils.containers import TrainingData
 from botorch.utils.testing import BotorchTestCase
@@ -37,13 +39,15 @@ def _get_random_mt_data(**tkwargs):
     return train_X, train_Y
 
 
-def _get_model(**tkwargs):
-    return _get_model_and_training_data(**tkwargs)[0]
+def _get_model(input_transform=None, **tkwargs):
+    return _get_model_and_training_data(input_transform=input_transform, **tkwargs)[0]
 
 
-def _get_model_and_training_data(**tkwargs):
+def _get_model_and_training_data(input_transform=None, **tkwargs):
     train_X, train_Y = _get_random_mt_data(**tkwargs)
-    model = MultiTaskGP(train_X, train_Y, task_feature=1)
+    model = MultiTaskGP(
+        train_X, train_Y, task_feature=1, input_transform=input_transform
+    )
     return model.to(**tkwargs), train_X, train_Y
 
 
@@ -53,14 +57,18 @@ def _get_model_single_output(**tkwargs):
     return model.to(**tkwargs)
 
 
-def _get_fixed_noise_model(**tkwargs):
-    return _get_fixed_noise_model_and_training_data(**tkwargs)[0]
+def _get_fixed_noise_model(input_transform=None, **tkwargs):
+    return _get_fixed_noise_model_and_training_data(
+        input_transform=input_transform, **tkwargs
+    )[0]
 
 
-def _get_fixed_noise_model_and_training_data(**tkwargs):
+def _get_fixed_noise_model_and_training_data(input_transform=None, **tkwargs):
     train_X, train_Y = _get_random_mt_data(**tkwargs)
     train_Yvar = torch.full_like(train_Y, 0.05)
-    model = FixedNoiseMultiTaskGP(train_X, train_Y, train_Yvar, task_feature=1)
+    model = FixedNoiseMultiTaskGP(
+        train_X, train_Y, train_Yvar, task_feature=1, input_transform=input_transform
+    )
     return model.to(**tkwargs), train_X, train_Y, train_Yvar
 
 
@@ -78,7 +86,10 @@ def _get_fixed_prior_model(**tkwargs):
     sd_prior = GammaPrior(2.0, 0.15)
     sd_prior._event_shape = torch.Size([2])
     model = MultiTaskGP(
-        train_X, train_Y, task_feature=1, prior=LKJCovariancePrior(2, 0.6, sd_prior)
+        train_X,
+        train_Y,
+        task_feature=1,
+        task_covar_prior=LKJCovariancePrior(2, 0.6, sd_prior),
     )
     return model.to(**tkwargs)
 
@@ -93,16 +104,28 @@ def _get_fixed_noise_and_prior_model(**tkwargs):
         train_Y,
         train_Yvar,
         task_feature=1,
-        prior=LKJCovariancePrior(2, 0.6, sd_prior),
+        task_covar_prior=LKJCovariancePrior(2, 0.6, sd_prior),
     )
     return model.to(**tkwargs)
 
 
 class TestMultiTaskGP(BotorchTestCase):
     def test_MultiTaskGP(self):
-        for dtype in (torch.float, torch.double):
+        bounds = torch.tensor([[-1.0, 0.0], [1.0, 1.0]])
+        for dtype, use_intf in itertools.product(
+            (torch.float, torch.double), (False, True)
+        ):
             tkwargs = {"device": self.device, "dtype": dtype}
-            model = _get_model(**tkwargs)
+            intf = (
+                Normalize(
+                    d=2, bounds=bounds.to(**tkwargs), transform_on_set_train_data=True
+                )
+                if use_intf
+                else None
+            )
+            model, train_X, _ = _get_model_and_training_data(
+                input_transform=intf, **tkwargs
+            )
             self.assertIsInstance(model, MultiTaskGP)
             self.assertEqual(model.num_outputs, 2)
             self.assertIsInstance(model.likelihood, GaussianLikelihood)
@@ -116,6 +139,8 @@ class TestMultiTaskGP(BotorchTestCase):
             self.assertEqual(
                 model.task_covar_module.covar_factor.shape[-1], model._rank
             )
+            if use_intf:
+                self.assertIsInstance(model.input_transform, Normalize)
 
             # test model fitting
             mll = ExactMarginalLogLikelihood(model.likelihood, model)
@@ -131,6 +156,13 @@ class TestMultiTaskGP(BotorchTestCase):
             self.assertEqual(posterior_f.mean.shape, torch.Size([2, 2]))
             self.assertEqual(posterior_f.variance.shape, torch.Size([2, 2]))
 
+            # check that training data has input transform applied
+            # check that the train inputs have been transformed and set on the model
+            if use_intf:
+                self.assertTrue(
+                    torch.equal(model.train_inputs[0], model.input_transform(train_X))
+                )
+
             # test that posterior w/ observation noise raises appropriate error
             with self.assertRaises(NotImplementedError):
                 model.posterior(test_x, observation_noise=True)
@@ -221,9 +253,21 @@ class TestMultiTaskGP(BotorchTestCase):
 
 class TestFixedNoiseMultiTaskGP(BotorchTestCase):
     def test_FixedNoiseMultiTaskGP(self):
-        for dtype in (torch.float, torch.double):
+        bounds = torch.tensor([[-1.0, 0.0], [1.0, 1.0]])
+        for dtype, use_intf in itertools.product(
+            (torch.float, torch.double), (False, True)
+        ):
             tkwargs = {"device": self.device, "dtype": dtype}
-            model = _get_fixed_noise_model(**tkwargs)
+            intf = (
+                Normalize(
+                    d=2, bounds=bounds.to(**tkwargs), transform_on_set_train_data=True
+                )
+                if use_intf
+                else None
+            )
+            model, train_X, _, _ = _get_fixed_noise_model_and_training_data(
+                input_transform=intf, **tkwargs
+            )
             self.assertIsInstance(model, FixedNoiseMultiTaskGP)
             self.assertEqual(model.num_outputs, 2)
             self.assertIsInstance(model.likelihood, FixedNoiseGaussianLikelihood)
@@ -237,6 +281,8 @@ class TestFixedNoiseMultiTaskGP(BotorchTestCase):
             self.assertEqual(
                 model.task_covar_module.covar_factor.shape[-1], model._rank
             )
+            if use_intf:
+                self.assertIsInstance(model.input_transform, Normalize)
 
             # test model fitting
             mll = ExactMarginalLogLikelihood(model.likelihood, model)
@@ -244,6 +290,13 @@ class TestFixedNoiseMultiTaskGP(BotorchTestCase):
                 warnings.filterwarnings("ignore", category=OptimizationWarning)
                 mll = fit_gpytorch_model(mll, options={"maxiter": 1}, max_retries=1)
 
+            # check that training data has input transform applied
+            # check that the train inputs have been transformed and set on the model
+            if use_intf:
+                self.assertTrue(
+                    torch.equal(model.train_inputs[0], model.input_transform(train_X))
+                )
+
             # test posterior
             test_x = torch.rand(2, 1, **tkwargs)
             posterior_f = model.posterior(test_x)
@@ -291,6 +344,8 @@ class TestFixedNoiseMultiTaskGP(BotorchTestCase):
             with self.assertRaises(RuntimeError):
                 FixedNoiseMultiTaskGP(train_X, train_Y, train_Yvar, 0, output_tasks=[2])
 
+            # test input transform
+
     def test_FixedNoiseMultiTaskGP_single_output(self):
         for dtype in (torch.float, torch.double):
             tkwargs = {"device": self.device, "dtype": dtype}
@@ -342,12 +397,43 @@ class TestFixedNoiseMultiTaskGP(BotorchTestCase):
             tkwargs = {"device": self.device, "dtype": dtype}
             model, train_X, train_Y = _get_model_and_training_data(**tkwargs)
             training_data = TrainingData(X=train_X, Y=train_Y)
-            # if task_features is missing, then raise error
-            with self.assertRaises(ValueError):
+            # Test that task features are required.
+            with self.assertRaisesRegex(ValueError, "`task_features` required"):
                 model.construct_inputs(training_data)
-            data_dict = model.construct_inputs(training_data, task_features=[0])
+            # Validate prior config.
+            with self.assertRaisesRegex(
+                ValueError, ".* only config for LKJ prior is supported"
+            ):
+                data_dict = model.construct_inputs(
+                    training_data,
+                    task_features=[0],
+                    prior_config={"use_LKJ_prior": False},
+                )
+            # Validate eta.
+            with self.assertRaisesRegex(ValueError, "eta must be a real number"):
+                data_dict = model.construct_inputs(
+                    training_data,
+                    task_features=[0],
+                    prior_config={"use_LKJ_prior": True, "eta": "not_number"},
+                )
+            # Test that presence of `prior` and `prior_config` kwargs at the
+            # same time causes error.
+            with self.assertRaisesRegex(ValueError, ".* one of `prior` and `prior_"):
+                data_dict = model.construct_inputs(
+                    training_data,
+                    task_features=[0],
+                    task_covar_prior=1,
+                    prior_config={"use_LKJ_prior": True, "eta": "not_number"},
+                )
+            data_dict = model.construct_inputs(
+                training_data,
+                task_features=[0],
+                prior_config={"use_LKJ_prior": True, "eta": 0.6},
+            )
             self.assertTrue(torch.equal(data_dict["train_X"], train_X))
             self.assertTrue(torch.equal(data_dict["train_Y"], train_Y))
+            self.assertEqual(data_dict["task_feature"], 0)
+            self.assertIsInstance(data_dict["task_covar_prior"], LKJCovariancePrior)
 
     def test_FixedNoiseMultiTaskGP_construct_inputs(self):
         for dtype in (torch.float, torch.double):
@@ -359,13 +445,29 @@ class TestFixedNoiseMultiTaskGP(BotorchTestCase):
                 train_Yvar,
             ) = _get_fixed_noise_model_and_training_data(**tkwargs)
             td_no_Yvar = TrainingData(X=train_X, Y=train_Y)
-            # if task_features is missing, then raise error
-            with self.assertRaisesRegex(ValueError, "task features required"):
-                model.construct_inputs(td_no_Yvar)
-            # if task_features is missing, then raise error
+            # Test that Yvar is required.
             with self.assertRaisesRegex(ValueError, "Yvar required"):
-                model.construct_inputs(td_no_Yvar, task_features=[0])
+                model.construct_inputs(td_no_Yvar)
             training_data = TrainingData(X=train_X, Y=train_Y, Yvar=train_Yvar)
-            data_dict = model.construct_inputs(training_data, task_features=[0])
+            # Test that task features are required.
+            with self.assertRaisesRegex(ValueError, "`task_features` required"):
+                model.construct_inputs(training_data)
+            # Validate prior config.
+            with self.assertRaisesRegex(
+                ValueError, ".* only config for LKJ prior is supported"
+            ):
+                data_dict = model.construct_inputs(
+                    training_data,
+                    task_features=[0],
+                    prior_config={"use_LKJ_prior": False},
+                )
+            data_dict = model.construct_inputs(
+                training_data,
+                task_features=[0],
+                prior_config={"use_LKJ_prior": True, "eta": 0.6},
+            )
             self.assertTrue(torch.equal(data_dict["train_X"], train_X))
             self.assertTrue(torch.equal(data_dict["train_Y"], train_Y))
+            self.assertTrue(torch.equal(data_dict["train_Yvar"], train_Yvar))
+            self.assertEqual(data_dict["task_feature"], 0)
+            self.assertIsInstance(data_dict["task_covar_prior"], LKJCovariancePrior)
