@@ -15,6 +15,7 @@ from botorch.utils.sampling import (
     batched_multinomial,
     construct_base_samples,
     construct_base_samples_from_posterior,
+    draw_sobol_samples,
     manual_seed,
     sample_hypersphere,
     sample_simplex,
@@ -158,6 +159,28 @@ class TestConstructBaseSamples(BotorchTestCase):
 
 
 class TestSampleUtils(BotorchTestCase):
+    def test_draw_sobol_samples(self):
+        batch_shapes = [None, [3, 5], torch.Size([2]), (5, 3, 2, 3), []]
+        for d, q, n, batch_shape, seed, dtype in itertools.product(
+            (1, 3),
+            (1, 2),
+            (2, 5),
+            batch_shapes,
+            (None, 1234),
+            (torch.float, torch.double),
+        ):
+            tkwargs = {"device": self.device, "dtype": dtype}
+            bounds = torch.stack([torch.rand(d), 1 + torch.rand(d)]).to(**tkwargs)
+            samples = draw_sobol_samples(
+                bounds=bounds, n=n, q=q, batch_shape=batch_shape, seed=seed
+            )
+            batch_shape = batch_shape or torch.Size()
+            self.assertEqual(samples.shape, torch.Size([n, *batch_shape, q, d]))
+            self.assertTrue(torch.all(samples >= bounds[0]))
+            self.assertTrue(torch.all(samples <= bounds[1]))
+            self.assertEqual(samples.device.type, self.device.type)
+            self.assertEqual(samples.dtype, dtype)
+
     def test_sample_simplex(self):
         for d, n, qmc, seed, dtype in itertools.product(
             (1, 2, 3), (2, 5), (False, True), (None, 1234), (torch.float, torch.double)
